<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Entity;

use Sylius\Component\Core\Model\ImageInterface;
use Sylius\Component\Resource\Model\TimestampableTrait;
use Symfony\Component\Validator\Constraints as Assert;

class Author implements AuthorInterface
{
    use TimestampableTrait;

    protected ?int $id = null;

    /** @Assert\NotBlank(groups={"default", "sylius"}) */
    protected ?string $username = null;

    protected ?ImageInterface $avatar = null;

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getUsername(): string
    {
        return (string) $this->username;
    }

    public function setUsername(?string $username): self
    {
        $this->username = $username;

        return $this;
    }

    public function getAvatar(): ?ImageInterface
    {
        return $this->avatar;
    }

    public function setAvatar(?ImageInterface $avatar): self
    {
        $avatar->setOwner($this);
        $this->avatar = $avatar;

        return $this;
    }

    public function __toString(): string
    {
        return $this->username;
    }
}
