<?php

declare(strict_types=1);

namespace Dedi\SyliusBlogPlugin\Factory;

use Dedi\SyliusBlogPlugin\Domain\Blog\Adapter\ArticleRepositoryInterface;
use Dedi\SyliusBlogPlugin\Entity\Comment;
use Dedi\SyliusBlogPlugin\Entity\CommentInterface;
use Sylius\Component\Core\Model\ChannelInterface;
use Sylius\Component\Core\Model\ShopUserInterface;
use Sylius\Component\Resource\Factory\FactoryInterface;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;

final class CommentFactory implements CommentFactoryInterface
{
    private readonly FactoryInterface $decoratedFactory;

    private ArticleRepositoryInterface $articleRepository;

    private readonly TokenStorageInterface $tokenStorage;

    public function __construct(FactoryInterface $decoratedFactory, ArticleRepositoryInterface $articleRepository, TokenStorageInterface $tokenStorage)
    {
        $this->decoratedFactory = $decoratedFactory;
        $this->articleRepository = $articleRepository;
        $this->tokenStorage = $tokenStorage;
    }

    public function createNew(): CommentInterface
    {
        /** @var CommentInterface $comment */
        $comment = $this->decoratedFactory->createNew();

        return $comment;
    }

    public function createNewWithArticle(ChannelInterface $channel, $articleSlug, $locale): CommentInterface
    {
        /** @var Comment $comment */
        $comment = $this->createNew();
        $comment->setArticle($this->articleRepository->findOneByChannelAndSlug($channel, $articleSlug, $locale));

        /** @var ShopUserInterface $shopUser */
        $shopUser = $this->tokenStorage->getToken()->getUser();

        $comment->setCustomer($shopUser->getCustomer());

        return $comment;
    }

    public function setArticleRepository(ArticleRepositoryInterface $articleRepository)
    {
        $this->articleRepository = $articleRepository;
    }
}
